@@ -1,10 +1,12 @@
 """Top-level package for Py3DEP."""
+from importlib.metadata import PackageNotFoundError, version
+
 from .exceptions import (
-    InvalidInputType,
-    InvalidInputValue,
-    MissingColumns,
-    MissingCRS,
-    MissingDependency,
+    DependencyError,
+    InputTypeError,
+    InputValueError,
+    MissingColumnError,
+    MissingCRSError,
 )
 from .print_versions import show_versions
 from .py3dep import (
@@ -18,13 +20,9 @@ from .py3dep import (
 from .utils import deg2mpm, fill_depressions
 
 try:
-    import importlib.metadata
-except ImportError:
-    import importlib_metadata
-
-    __version__ = importlib_metadata.version("py3dep")
-else:
-    __version__ = importlib.metadata.version("py3dep")
+    __version__ = version("py3dep")
+except PackageNotFoundError:
+    __version__ = "999"
 
 __all__ = [
     # Functions
@@ -38,11 +36,11 @@ __all__ = [
     "elevation_profile",
     "show_versions",
     # Exceptions
-    "MissingColumns",
-    "MissingCRS",
-    "MissingDependency",
-    "InvalidInputType",
-    "InvalidInputValue",
+    "MissingColumnError",
+    "MissingCRSError",
+    "DependencyError",
+    "InputTypeError",
+    "InputValueError",
     # Constants
     "__version__",
 ]
