@@ -14,16 +14,16 @@ import pyproj
 import rioxarray  # noqa: F401
 import shapely.ops as ops
 import xarray as xr
-from async_retriever import ServiceError
-from pygeoogc import WMS, ArcGISRESTful, ServiceURL
+from pygeoogc import WMS, ArcGISRESTful, ServiceURL, ZeroMatchedError
 from pygeoogc import utils as ogc_utils
 from pygeoutils import GeoBSpline
 from pygeoutils.pygeoutils import Spline
+from rasterio import RasterioIOError
 from rasterio.enums import Resampling
 from shapely.geometry import LineString, MultiLineString, MultiPolygon, Polygon
 
 from . import utils
-from .exceptions import InvalidInputType, InvalidInputValue
+from .exceptions import InputTypeError, InputValueError, ServiceUnavailableError
 
 DEF_CRS = "epsg:4326"
 EXPIRE = -1
@@ -102,7 +102,7 @@ def get_map(
     _layers = list(layers) if isinstance(layers, (list, tuple)) else [layers]
     invalid = [lyr for lyr in _layers if lyr not in LAYERS]
     if len(invalid) > 0:
-        raise InvalidInputValue(f"layers ({invalid})", LAYERS)
+        raise InputValueError(f"layers ({invalid})", LAYERS)
 
     if "DEM" in _layers:
         _layers[_layers.index("DEM")] = "None"
@@ -111,16 +111,25 @@ def get_map(
 
     wms_url = ServiceURL().wms.nm_3dep
     valid_crs = ogc_utils.valid_wms_crs(wms_url)
+
+    if len(valid_crs) == 0:
+        raise ServiceUnavailableError(wms_url)
+
     if ogc_utils.validate_crs(crs).lower() not in valid_crs:
-        raise InvalidInputValue("crs", valid_crs)
+        raise InputValueError("crs", valid_crs)
 
     _geometry = geoutils.geo2polygon(geometry, geo_crs, crs)
     wms = WMS(wms_url, layers=_layers, outformat="image/tiff", crs=crs, validation=False)
-    r_dict = wms.getmap_bybox(_geometry.bounds, resolution, box_crs=crs)
-    if isinstance(geometry, (Polygon, MultiPolygon)):
-        ds = geoutils.gtiff2xarray(r_dict, _geometry, crs)
-    else:
-        ds = geoutils.gtiff2xarray(r_dict)
+    r_dict = wms.getmap_bybox(_geometry.bounds, resolution, box_crs=crs, max_px=10000000)
+
+    try:
+        if isinstance(geometry, (Polygon, MultiPolygon)):
+            ds = geoutils.gtiff2xarray(r_dict, _geometry, crs)
+        else:
+            ds = geoutils.gtiff2xarray(r_dict)
+    except RasterioIOError as ex:
+        raise ServiceUnavailableError(wms_url) from ex
+
     valid_layers = wms.get_validlayers()
     return utils.rename_layers(ds, list(valid_layers))  # type: ignore
 
@@ -205,7 +214,7 @@ class ElevationByCoords:
         self.coords = gpd.GeoSeries(gpd.points_from_xy(*zip(*self.coords)), crs=self.crs)
         valid_sources = ["tnm", "airmap", "tep"]
         if self.source not in valid_sources:
-            raise InvalidInputValue("source", valid_sources)
+            raise InputValueError("source", valid_sources)
 
     def airmap(self) -> List[float]:
         """Return list of elevations in meters."""
@@ -252,9 +261,12 @@ class ElevationByCoords:
 
         points_proj = self.coords.to_crs(wms_3dep.crs)  # type: ignore
         bounds = points_proj.buffer(30, cap_style=3)
-        da_list: List[xr.DataArray] = [
-            geoutils.gtiff2xarray(get_dem(b.bounds)) for b in bounds  # type: ignore
-        ]
+        try:
+            da_list: List[xr.DataArray] = [
+                geoutils.gtiff2xarray(get_dem(b.bounds)) for b in bounds  # type: ignore
+            ]
+        except RasterioIOError as ex:
+            raise ServiceUnavailableError(ServiceURL().wms.nm_3dep) from ex
 
         def get_value(da: xr.DataArray, x: float, y: float) -> float:
             nodata = da.attrs["nodatavals"][0]
@@ -339,7 +351,7 @@ def elevation_profile(
     lines : LineString or MultiLineString
         Line segment(s) to be profiled. If its type is ``MultiLineString``,
         it will be converted to a single ``LineString`` and if this operation
-        fails, a ``InvalidInputType`` will be raised.
+        fails, a ``InputTypeError`` will be raised.
     spacing : float
         Spacing between the sample points along the line in meters.
     dem_res : float, optional
@@ -355,26 +367,25 @@ def elevation_profile(
         of the line in meters.
     """
     if not isinstance(lines, (LineString, MultiLineString)):
-        raise InvalidInputType("lines", "LineString or MultiLineString")
+        raise InputTypeError("lines", "LineString or MultiLineString")
 
     if isinstance(lines, MultiLineString):
         path = ops.linemerge(lines)
         if not isinstance(path, LineString):
-            raise InvalidInputType("lines", "mergeable to a single line")
+            raise InputTypeError("lines", "mergeable to a single line")
     else:
         path = lines
 
     crs_prj = "epsg:5070"
     geom = gpd.GeoSeries([path], crs=crs).to_crs(crs_prj)
-    geom_buff = geom.buffer(20 * dem_res).unary_union
+    geom_buff = geom.buffer(5 * dem_res).unary_union.bounds
     dem = get_map("DEM", geom_buff, dem_res, crs_prj)
 
     n_seg = int(np.ceil(geom.length.sum() / spacing)) * 100
     x, y, distance = __get_spline_params(geom.geometry[0], n_seg, spacing, crs_prj)
     xp, yp = zip(*ogc_utils.match_crs(list(zip(x, y)), crs_prj, dem.rio.crs))
 
-    elevation = dem.interp(x=("z", list(xp)), y=("z", list(yp)), method="nearest")
-    elevation = elevation.drop_vars("spatial_ref")
+    elevation = dem.interp(x=("z", list(xp)), y=("z", list(yp)))
     xp, yp = zip(*ogc_utils.match_crs(list(zip(x, y)), crs_prj, crs))
     elevation["x"], elevation["y"] = ("z", list(xp)), ("z", list(yp))
     elevation["distance"] = ("z", distance)
@@ -410,7 +421,7 @@ def check_3dep_availability(
     {'1m': True, '3m': False, '5m': False, '10m': True, '30m': True, '60m': False, 'topobathy': False}
     """
     if not isinstance(bbox, Sequence) or len(bbox) != 4:
-        raise InvalidInputType("bbox", "a tuple of length 4")
+        raise InputTypeError("bbox", "a tuple of length 4")
 
     res_layers = {
         "1m": 18,
@@ -426,7 +437,7 @@ def check_3dep_availability(
 
     def _check(lyr: int) -> bool:
         wms = ArcGISRESTful(url, lyr)
-        with contextlib.suppress(ServiceError, TypeError):
+        with contextlib.suppress(ZeroMatchedError):
             return len(list(wms.oids_bygeom(_bbox))[0]) > 0
         return False
 
@@ -471,7 +482,7 @@ def query_3dep_sources(
     {'1m': 4}
     """
     if not isinstance(bbox, Sequence) or len(bbox) != 4:
-        raise InvalidInputType("bbox", "a tuple of length 4")
+        raise InputTypeError("bbox", "a tuple of length 4")
     res_layers = {
         "1m": 18,
         "3m": 19,
@@ -482,7 +493,7 @@ def query_3dep_sources(
         "topobathy": 30,
     }
     if res is not None and res not in res_layers:
-        raise InvalidInputValue("res", list(res_layers.keys()))
+        raise InputValueError("res", list(res_layers.keys()))
 
     layers = {res: res_layers[res]} if res is not None else res_layers
 
@@ -491,7 +502,7 @@ def query_3dep_sources(
 
     def _check(lyr: int) -> Optional[gpd.GeoDataFrame]:
         wms = utils.RESTful(url, lyr)
-        with contextlib.suppress(ServiceError, TypeError):
+        with contextlib.suppress(ZeroMatchedError):
             return wms.bygeom(_bbox)
         return None
 
