@@ -2,7 +2,7 @@ import pytest
 from shapely.geometry import Polygon
 
 import py3dep
-from py3dep import InvalidInputType, InvalidInputValue
+from py3dep import InputTypeError, InputValueError
 
 DEF_CRS = "epsg:4326"
 GEOM = Polygon(
@@ -19,18 +19,18 @@ else:
 
 @pytest.mark.skipif(has_typeguard, reason="Broken if Typeguard is enabled")
 def test_wrong_bbox():
-    with pytest.raises(InvalidInputType) as ex:
+    with pytest.raises(InputTypeError) as ex:
         _ = py3dep.check_3dep_availability((1, 2, 3))
         assert "tuple of length 4" in str(ex.value)
 
 
 def test_wrong_layer():
-    with pytest.raises(InvalidInputValue) as ex:
+    with pytest.raises(InputValueError) as ex:
         _ = py3dep.get_map("None", GEOM.bounds, 1e3)
         assert "DEM" in str(ex.value)
 
 
 def test_wrong_crs():
-    with pytest.raises(InvalidInputValue) as ex:
+    with pytest.raises(InputValueError) as ex:
         _ = py3dep.get_map("None", GEOM.bounds, 1e3, DEF_CRS, "ESRI:102003")
         assert "crs" in str(ex.value)
